pub enum Op {
Replace {
path: Path,
html: Html,
},
SetText {
path: Path,
text: String,
},
SetAttr {
path: Path,
name: String,
value: String,
},
RemoveAttr {
path: Path,
name: String,
},
Insert {
path: Path,
index: u32,
html: Html,
},
Remove {
path: Path,
index: u32,
},
Move {
path: Path,
from: u32,
to: u32,
},
}Variants
Replace
Replace the node at path wholesale (tag or key changed).
SetText
SetAttr
RemoveAttr
Insert
Insert html as child index of the element at path.
Remove
Move
Move child from to to within the element at path; from > to always.
Implementations