proposal

Function proposal 

pub fn proposal<'a>(
    actor: &str,
    claims: impl IntoIterator<Item = (&'a str, &'a str)>,
    command: Value,
) -> Value
Proposal — a command and who proposed it, which is what validate is given and the only place a Session reaches (3.5).