pub fn from_program(program: &Program) -> GraphBuilderExpand description
Read the vertices and edges of a checked program.
One walk of every definition body, so O(program size).
pub fn from_program(program: &Program) -> GraphBuilderRead the vertices and edges of a checked program.
One walk of every definition body, so O(program size).