pub struct Change<K, V> {
pub key: K,
pub old: Option<V>,
pub new: Option<V>,
}Expand description
What happened to one key between two versions of a map.
old and new are both present for an update, one of them for an insert or a remove. Both
absent never occurs.
Fields
key: Kold: Option<V>new: Option<V>Trait Implementations
impl<K: Eq, V: Eq> Eq for Change<K, V>
impl<K, V> StructuralPartialEq for Change<K, V>