pub struct StateRole {
pub name: Arc<str>,
pub ty: Ty,
pub field: Option<Arc<str>>,
pub node: SigId,
}Expand description
One durable accumulator the program declared.
Fields
name: Arc<str>ty: Tyfield: Option<Arc<str>>The field this fold occupies in the fused accumulator, when there is more than one fold.
None when the program has a single fold and its own type is the accumulator.
node: SigIdTrait Implementations