pub fn node_cost(
tier: Tier,
row: &Row,
work: i64,
state: Option<&Ty>,
types: &BTreeMap<Arc<str>, TyDecl>,
) -> CostExpand description
The node cost of putting row on tier, given how much work the node does and — for a durable
fold — what its accumulator looks like.