pub fn keyed(key: &str, message: &str) -> String
A message authentication code over message under key, as 64 lowercase hex digits.
message
key
The one function in the language whose input is a secret[Str] and whose output is not secret.
secret[Str]